@@ -1,6 +1,12 @@
 from mongomock import DuplicateKeyError, helpers
 
 
+try:
+    from beanie.odm.fields import ExpressionField
+except ModuleNotFoundError:
+    ExpressionField = None
+
+
 def _provide_error_details(collection, data, exception):
     if not isinstance(exception, DuplicateKeyError):
         return exception
@@ -62,7 +68,8 @@ def _normalize_strings(obj):
     if isinstance(obj, dict):
         return {_normalize_strings(k): _normalize_strings(v) for k, v in obj.items()}
 
-    if isinstance(obj, str):
+    # make sure we won't fail while working with beanie
+    if ExpressionField and isinstance(obj, ExpressionField):
         return str(obj)
 
     return obj
